@@ -1,30 +1,46 @@
+from __future__ import annotations
+
 import dataclasses
 import warnings
-from typing import Any, List, Optional, Sequence, Tuple, Type, cast
+from typing import (
+    TYPE_CHECKING,
+    Any,
+    Optional,
+    cast,
+)
 
 from pydantic import BaseModel
-from pydantic.fields import ModelField
 
-from strawberry.auto import StrawberryAuto
+from strawberry.experimental.pydantic._compat import (
+    CompatModelField,
+    PydanticCompat,
+    lenient_issubclass,
+)
 from strawberry.experimental.pydantic.utils import (
     get_private_fields,
     get_strawberry_type_from_model,
     normalize_type,
 )
-from strawberry.object_type import _process_type, _wrap_dataclass
+from strawberry.types.auto import StrawberryAuto
+from strawberry.types.object_type import _process_type, _wrap_dataclass
 from strawberry.types.type_resolver import _get_fields
 from strawberry.utils.typing import get_list_annotation, is_list
 
 from .exceptions import MissingFieldsListError
 
+if TYPE_CHECKING:
+    from collections.abc import Callable, Sequence
 
-def get_type_for_field(field: ModelField):
+    from strawberry.types.base import WithStrawberryObjectDefinition
+
+
+def get_type_for_field(field: CompatModelField) -> type[None | list] | Any:
     type_ = field.outer_type_
     type_ = normalize_type(type_)
     return field_type_to_type(type_)
 
 
-def field_type_to_type(type_):
+def field_type_to_type(type_: type) -> Any | list[Any] | None:
     error_class: Any = str
     strawberry_type: Any = error_class
 
@@ -33,46 +49,47 @@ def field_type_to_type(type_):
 
         if is_list(child_type):
             strawberry_type = field_type_to_type(child_type)
-        elif issubclass(child_type, BaseModel):
+        elif lenient_issubclass(child_type, BaseModel):
             strawberry_type = get_strawberry_type_from_model(child_type)
         else:
-            strawberry_type = List[error_class]
+            strawberry_type = list[error_class]
 
-        strawberry_type = Optional[strawberry_type]
-    elif issubclass(type_, BaseModel):
+        strawberry_type = Optional[strawberry_type]  # noqa: UP045
+    elif lenient_issubclass(type_, BaseModel):
         strawberry_type = get_strawberry_type_from_model(type_)
-        return Optional[strawberry_type]
+        return Optional[strawberry_type]  # noqa: UP045
 
-    return Optional[List[strawberry_type]]
+    return Optional[list[strawberry_type]]  # noqa: UP045
 
 
 def error_type(
-    model: Type[BaseModel],
+    model: type[BaseModel],
     *,
-    fields: List[str] = None,
-    name: Optional[str] = None,
-    description: Optional[str] = None,
-    directives: Optional[Sequence[object]] = (),
-    all_fields: bool = False
-):
-    def wrap(cls):
-        model_fields = model.__fields__
-        fields_set = set(fields) if fields else set([])
+    fields: list[str] | None = None,
+    name: str | None = None,
+    description: str | None = None,
+    directives: Sequence[object] | None = (),
+    all_fields: bool = False,
+) -> Callable[..., type]:
+    def wrap(cls: type) -> type:
+        compat = PydanticCompat.from_model(model)
+        model_fields = compat.get_model_fields(model)
+        fields_set = set(fields) if fields else set()
 
         if fields:
             warnings.warn(
                 "`fields` is deprecated, use `auto` type annotations instead",
                 DeprecationWarning,
+                stacklevel=2,
             )
 
         existing_fields = getattr(cls, "__annotations__", {})
-        fields_set = fields_set.union(
-            set(
-                name
-                for name, type_ in existing_fields.items()
-                if isinstance(type_, StrawberryAuto)
-            )
-        )
+        auto_fields_set = {
+            name
+            for name, type_ in existing_fields.items()
+            if isinstance(type_, StrawberryAuto)
+        }
+        fields_set |= auto_fields_set
 
         if all_fields:
             if fields_set:
@@ -86,7 +103,7 @@ def error_type(
         if not fields_set:
             raise MissingFieldsListError(cls)
 
-        all_model_fields: List[Tuple[str, Any, dataclasses.Field]] = [
+        all_model_fields: list[tuple[str, Any, dataclasses.Field]] = [
             (
                 name,
                 get_type_for_field(field),
@@ -96,19 +113,20 @@ def error_type(
             if name in fields_set
         ]
 
-        wrapped = _wrap_dataclass(cls)
-        extra_fields = cast(List[dataclasses.Field], _get_fields(wrapped))
+        wrapped: type[WithStrawberryObjectDefinition] = _wrap_dataclass(cls)
+        extra_fields = cast("list[dataclasses.Field]", _get_fields(wrapped, {}))
         private_fields = get_private_fields(wrapped)
 
         all_model_fields.extend(
             (
-                (
-                    field.name,
-                    field.type,
-                    field,
-                )
-                for field in extra_fields + private_fields
-                if not isinstance(field.type, StrawberryAuto)
+                field.name,
+                field.type,
+                field,
+            )
+            for field in extra_fields + private_fields
+            if (
+                field.name not in auto_fields_set
+                and not isinstance(field.type, StrawberryAuto)
             )
         )
 
@@ -128,7 +146,7 @@ def error_type(
         )
 
         model._strawberry_type = cls  # type: ignore[attr-defined]
-        cls._pydantic_type = model
+        cls._pydantic_type = model  # type: ignore[attr-defined]
         return cls
 
     return wrap
