@@ -1,12 +1,14 @@
 from __future__ import annotations
 
-from typing import TYPE_CHECKING, Any, Callable
+from typing import TYPE_CHECKING, Any
 
 from strawberry.extensions import SchemaExtension
 from strawberry.types.nodes import convert_arguments
 from strawberry.utils.await_maybe import await_maybe
 
 if TYPE_CHECKING:
+    from collections.abc import Callable
+
     from graphql import DirectiveNode, GraphQLResolveInfo
 
     from strawberry.directive import StrawberryDirective
@@ -29,7 +31,9 @@ class DirectivesExtension(SchemaExtension):
     ) -> AwaitableOrValue[Any]:
         value = await await_maybe(_next(root, info, *args, **kwargs))
 
-        for directive in info.field_nodes[0].directives:
+        nodes = list(info.field_nodes)
+
+        for directive in nodes[0].directives:
             if directive.name.value in SPECIFIED_DIRECTIVES:
                 continue
             strawberry_directive, arguments = process_directive(directive, value, info)
@@ -49,7 +53,9 @@ class DirectivesExtensionSync(SchemaExtension):
     ) -> AwaitableOrValue[Any]:
         value = _next(root, info, *args, **kwargs)
 
-        for directive in info.field_nodes[0].directives:
+        nodes = list(info.field_nodes)
+
+        for directive in nodes[0].directives:
             if directive.name.value in SPECIFIED_DIRECTIVES:
                 continue
             strawberry_directive, arguments = process_directive(directive, value, info)
