@@ -1,6 +1,5 @@
 from collections.abc import Iterator
 from functools import lru_cache
-from typing import Optional
 
 from strawberry.extensions.base_extension import SchemaExtension
 
@@ -22,7 +21,7 @@ class ValidationCache(SchemaExtension):
     ```
     """
 
-    def __init__(self, maxsize: Optional[int] = None) -> None:
+    def __init__(self, maxsize: int | None = None) -> None:
         """Initialize the ValidationCache.
 
         Args:
@@ -43,7 +42,7 @@ class ValidationCache(SchemaExtension):
             execution_context.graphql_document,
             execution_context.validation_rules,
         )
-        execution_context.errors = errors
+        execution_context.pre_execution_errors = errors
         yield
 
 
