@@ -36,7 +36,7 @@ if TYPE_CHECKING:
     from strawberry.federation.schema_directives import ComposeDirective
     from strawberry.schema.config import StrawberryConfig
     from strawberry.schema_directive import StrawberrySchemaDirective
-    from strawberry.types.enum import EnumDefinition
+    from strawberry.types.enum import StrawberryEnumDefinition
     from strawberry.types.scalar import ScalarDefinition, ScalarWrapper
 
 
@@ -407,7 +407,7 @@ def _has_federation_keys(
     definition: Union[
         StrawberryObjectDefinition,
         "ScalarDefinition",
-        "EnumDefinition",
+        "StrawberryEnumDefinition",
         "StrawberryUnion",
     ],
 ) -> bool:
