@@ -19,13 +19,16 @@ from typing import (
     ClassVar,
     ForwardRef,
     Generic,
-    Optional,
+    Literal,
+    TypeAlias,
     TypeVar,
     Union,
     cast,
+    get_args,
+    get_origin,
     overload,
 )
-from typing_extensions import Literal, Self, TypeAlias, get_args, get_origin
+from typing_extensions import Self
 
 from strawberry.relay.exceptions import NodeIDAnnotationError
 from strawberry.types.base import (
@@ -56,12 +59,9 @@ if TYPE_CHECKING:
 
 _T = TypeVar("_T")
 
-NodeIterableType: TypeAlias = Union[
-    Iterator[_T],
-    Iterable[_T],
-    AsyncIterator[_T],
-    AsyncIterable[_T],
-]
+NodeIterableType: TypeAlias = (
+    Iterator[_T] | Iterable[_T] | AsyncIterator[_T] | AsyncIterable[_T]
+)
 NodeType = TypeVar("NodeType", bound="Node")
 
 PREFIX = "arrayconnection"
@@ -110,7 +110,7 @@ class GlobalID:
         return to_base64(self.type_name, self.node_id)
 
     @classmethod
-    def from_id(cls, value: Union[str, ID]) -> Self:
+    def from_id(cls, value: str | ID) -> Self:
         """Create a new GlobalID from parsing the given value.
 
         Args:
@@ -158,7 +158,7 @@ class GlobalID:
         *,
         required: bool = ...,
         ensure_type: None = ...,
-    ) -> Optional[Node]: ...
+    ) -> Node | None: ...
 
     async def resolve_node(self, info, *, required=False, ensure_type=None) -> Any:
         """Resolve the type name and node id info to the node itself.
@@ -268,7 +268,7 @@ class GlobalID:
         *,
         required: bool = ...,
         ensure_type: None = ...,
-    ) -> Optional[Node]: ...
+    ) -> Node | None: ...
 
     def resolve_node_sync(self, info, *, required=False, ensure_type=None) -> Any:
         """Resolve the type name and node id info to the node itself.
@@ -378,7 +378,7 @@ class Node:
     ```
     """
 
-    _id_attr: ClassVar[Optional[str]] = None
+    _id_attr: ClassVar[str | None] = None
 
     @field(name="id", description="The Globally Unique ID of this object")
     @classmethod
@@ -513,7 +513,7 @@ class Node:
         info: Info,
         node_ids: Iterable[str],
         required: Literal[False] = ...,
-    ) -> AwaitableOrValue[Iterable[Optional[Self]]]: ...
+    ) -> AwaitableOrValue[Iterable[Self | None]]: ...
 
     @overload
     @classmethod
@@ -523,10 +523,7 @@ class Node:
         info: Info,
         node_ids: Iterable[str],
         required: bool,
-    ) -> Union[
-        AwaitableOrValue[Iterable[Self]],
-        AwaitableOrValue[Iterable[Optional[Self]]],
-    ]: ...
+    ) -> AwaitableOrValue[Iterable[Self]] | AwaitableOrValue[Iterable[Self | None]]: ...
 
     @classmethod
     def resolve_nodes(
@@ -577,7 +574,7 @@ class Node:
         *,
         info: Info,
         required: Literal[False] = ...,
-    ) -> AwaitableOrValue[Optional[Self]]: ...
+    ) -> AwaitableOrValue[Self | None]: ...
 
     @overload
     @classmethod
@@ -587,7 +584,7 @@ class Node:
         *,
         info: Info,
         required: bool,
-    ) -> AwaitableOrValue[Optional[Self]]: ...
+    ) -> AwaitableOrValue[Self | None]: ...
 
     @classmethod
     def resolve_node(
@@ -596,7 +593,7 @@ class Node:
         *,
         info: Info,
         required: bool = False,
-    ) -> AwaitableOrValue[Optional[Self]]:
+    ) -> AwaitableOrValue[Self | None]:
         """Resolve a node given its id.
 
         This method is a convenience method that calls `resolve_nodes` for
@@ -641,10 +638,10 @@ class PageInfo:
     has_previous_page: bool = field(
         description="When paginating backwards, are there more items?",
     )
-    start_cursor: Optional[str] = field(
+    start_cursor: str | None = field(
         description="When paginating backwards, the cursor to continue.",
     )
-    end_cursor: Optional[str] = field(
+    end_cursor: str | None = field(
         description="When paginating forwards, the cursor to continue.",
     )
 
@@ -715,11 +712,11 @@ class Connection(Generic[NodeType]):
         nodes: NodeIterableType[NodeType],
         *,
         info: Info,
-        before: Optional[str] = None,
-        after: Optional[str] = None,
-        first: Optional[int] = None,
-        last: Optional[int] = None,
-        max_results: Optional[int] = None,
+        before: str | None = None,
+        after: str | None = None,
+        first: int | None = None,
+        last: int | None = None,
+        max_results: int | None = None,
         **kwargs: Any,
     ) -> AwaitableOrValue[Self]:
         """Resolve a connection from nodes.
@@ -762,16 +759,16 @@ class ListConnection(Connection[NodeType]):
     )
 
     @classmethod
-    def resolve_connection(  # noqa: PLR0915
+    def resolve_connection(
         cls,
         nodes: NodeIterableType[NodeType],
         *,
         info: Info,
-        before: Optional[str] = None,
-        after: Optional[str] = None,
-        first: Optional[int] = None,
-        last: Optional[int] = None,
-        max_results: Optional[int] = None,
+        before: str | None = None,
+        after: str | None = None,
+        first: int | None = None,
+        last: int | None = None,
+        max_results: int | None = None,
         **kwargs: Any,
     ) -> AwaitableOrValue[Self]:
         """Resolve a connection from the list of nodes.
@@ -820,7 +817,7 @@ class ListConnection(Connection[NodeType]):
             async def resolver() -> Self:
                 try:
                     iterator = cast(
-                        "Union[AsyncIterator[NodeType], AsyncIterable[NodeType]]",
+                        "AsyncIterator[NodeType] | AsyncIterable[NodeType]",
                         cast("Sequence", nodes)[
                             slice_metadata.start : slice_metadata.overfetch
                         ],
@@ -886,7 +883,7 @@ class ListConnection(Connection[NodeType]):
 
         try:
             iterator = cast(
-                "Union[Iterator[NodeType], Iterable[NodeType]]",
+                "Iterator[NodeType] | Iterable[NodeType]",
                 cast("Sequence", nodes)[
                     slice_metadata.start : slice_metadata.overfetch
                 ],
