@@ -1,12 +1,19 @@
 from __future__ import annotations
 
 from dataclasses import InitVar, dataclass, field
-from typing import Any, Callable
+from typing import TYPE_CHECKING, Any, TypedDict
 
 from strawberry.types.info import Info
 
 from .name_converter import NameConverter
 
+if TYPE_CHECKING:
+    from collections.abc import Callable
+
+
+class BatchingConfig(TypedDict):
+    max_operations: int
+
 
 @dataclass
 class StrawberryConfig:
@@ -17,7 +24,9 @@ class StrawberryConfig:
     relay_use_legacy_global_id: bool = False
     disable_field_suggestions: bool = False
     info_class: type[Info] = Info
+    enable_experimental_incremental_execution: bool = False
     _unsafe_disable_same_type_validation: bool = False
+    batching_config: BatchingConfig | None = None
 
     def __post_init__(
         self,
