@@ -89,7 +89,7 @@ if TYPE_CHECKING:
 
     from strawberry.directive import StrawberryDirective
     from strawberry.types.base import StrawberryType
-    from strawberry.types.enum import EnumDefinition
+    from strawberry.types.enum import StrawberryEnumDefinition
     from strawberry.types.field import StrawberryField
     from strawberry.types.scalar import ScalarDefinition, ScalarWrapper
     from strawberry.types.union import StrawberryUnion
@@ -438,7 +438,7 @@ class Schema(BaseSchema):
     ) -> (
         StrawberryObjectDefinition
         | ScalarDefinition
-        | EnumDefinition
+        | StrawberryEnumDefinition
         | StrawberryUnion
         | None
     ):
@@ -913,7 +913,7 @@ class Schema(BaseSchema):
         for concrete_type in self.schema_converter.type_map.values():
             type_def = concrete_type.definition
 
-            # This can be a TypeDefinition, EnumDefinition, ScalarDefinition
+            # This can be a TypeDefinition, StrawberryEnumDefinition, ScalarDefinition
             # or UnionDefinition
             if not isinstance(type_def, StrawberryObjectDefinition):
                 continue
