@@ -1,6 +1,5 @@
 import datetime
 import decimal
-from typing import Dict
 from uuid import UUID
 
 from graphql import (
@@ -12,13 +11,15 @@ from graphql import (
     GraphQLString,
 )
 
-from strawberry.custom_scalar import ScalarDefinition
 from strawberry.file_uploads.scalars import Upload
 from strawberry.scalars import ID
 from strawberry.schema.types import base_scalars
+from strawberry.types.scalar import ScalarDefinition
 
 
 def _make_scalar_type(definition: ScalarDefinition) -> GraphQLScalarType:
+    from strawberry.schema.schema_converter import GraphQLCoreConverter
+
     return GraphQLScalarType(
         name=definition.name,
         description=definition.description,
@@ -26,6 +27,7 @@ def _make_scalar_type(definition: ScalarDefinition) -> GraphQLScalarType:
         serialize=definition.serialize,
         parse_value=definition.parse_value,
         parse_literal=definition.parse_literal,
+        extensions={GraphQLCoreConverter.DEFINITION_BACKREF: definition},
     )
 
 
@@ -38,14 +40,15 @@ def _make_scalar_definition(scalar_type: GraphQLScalarType) -> ScalarDefinition:
         parse_literal=scalar_type.parse_literal,
         parse_value=scalar_type.parse_value,
         implementation=scalar_type,
+        origin=scalar_type,
     )
 
 
-def _get_scalar_definition(scalar) -> ScalarDefinition:
-    return scalar._scalar_definition
+def _get_scalar_definition(scalar: type) -> ScalarDefinition:
+    return scalar._scalar_definition  # type: ignore[attr-defined]
 
 
-DEFAULT_SCALAR_REGISTRY: Dict[object, ScalarDefinition] = {
+DEFAULT_SCALAR_REGISTRY: dict[object, ScalarDefinition] = {
     type(None): _get_scalar_definition(base_scalars.Void),
     None: _get_scalar_definition(base_scalars.Void),
     str: _make_scalar_definition(GraphQLString),
@@ -60,3 +63,11 @@ DEFAULT_SCALAR_REGISTRY: Dict[object, ScalarDefinition] = {
     datetime.time: _get_scalar_definition(base_scalars.Time),
     decimal.Decimal: _get_scalar_definition(base_scalars.Decimal),
 }
+
+
+__all__ = [
+    "DEFAULT_SCALAR_REGISTRY",
+    "_get_scalar_definition",
+    "_make_scalar_definition",
+    "_make_scalar_type",
+]
