@@ -10,16 +10,20 @@ def to_camel_case(snake_str: str) -> str:
     return components[0] + "".join(x.capitalize() if x else "_" for x in components[1:])
 
 
-# From this response in Stackoverflow
-# http://stackoverflow.com/a/1176023/1072990
-def to_snake_case(name: str) -> str:
-    s1 = re.sub(r"(.)([A-Z][a-z]+)", r"\1_\2", name)
-    return re.sub(r"([a-z0-9])([A-Z])", r"\1_\2", s1).lower()
+TO_KEBAB_CASE_RE = re.compile("((?<=[a-z0-9])[A-Z]|(?!^)[A-Z](?=[a-z]))")
 
 
-def to_const(string: str) -> str:
-    return re.sub(r"[\W|^]+", "_", string).upper()
+def to_kebab_case(name: str) -> str:
+    return TO_KEBAB_CASE_RE.sub(r"-\1", name).lower()
 
 
 def capitalize_first(name: str) -> str:
     return name[0].upper() + name[1:]
+
+
+def to_snake_case(name: str) -> str:
+    name = re.sub("(.)([A-Z][a-z]+)", r"\1_\2", name)
+    return re.sub("([a-z0-9])([A-Z])", r"\1_\2", name).lower()
+
+
+__all__ = ["capitalize_first", "to_camel_case", "to_kebab_case", "to_snake_case"]
