@@ -8,12 +8,10 @@ def test_interface_object():
     class SomeInterface:
         id: strawberry.ID
 
-    schema = strawberry.federation.Schema(
-        types=[SomeInterface], enable_federation_2=True
-    )
+    schema = strawberry.federation.Schema(types=[SomeInterface])
 
     expected = """
-        schema @link(url: "https://specs.apollo.dev/federation/v2.7", import: ["@interfaceObject", "@key"]) {
+        schema @link(url: "https://specs.apollo.dev/federation/v2.11", import: ["@interfaceObject", "@key"]) {
           query: Query
         }
 
