@@ -1,11 +1,12 @@
 from __future__ import annotations
 
-from typing_extensions import Literal
+from typing import Literal
 
 import pytest
 
 from strawberry.http import GraphQLHTTPResponse
 from strawberry.types import ExecutionResult
+from tests.views.schema import schema
 
 from .clients.base import HttpClient
 
@@ -21,7 +22,7 @@ def process_result(result: ExecutionResult) -> GraphQLHTTPResponse:
 
 @pytest.fixture
 def http_client(http_client_class) -> HttpClient:
-    return http_client_class(result_override=process_result)
+    return http_client_class(schema, result_override=process_result)
 
 
 @pytest.mark.parametrize("method", ["get", "post"])
