@@ -1,4 +1,4 @@
-from typing import TYPE_CHECKING, Annotated, Optional
+from typing import TYPE_CHECKING, Annotated
 
 import strawberry
 
@@ -8,9 +8,10 @@ if TYPE_CHECKING:
 
 @strawberry.type
 class TypeA:
-    list_of_b: Optional[
+    list_of_b: (
         list[Annotated["TypeB", strawberry.lazy("tests.schema.test_lazy.type_b")]]
-    ] = None
+        | None
+    ) = None
 
     @strawberry.field
     def type_b(self) -> Annotated["TypeB", strawberry.lazy(".type_b")]:
