@@ -6,7 +6,7 @@ import json
 import time
 from collections.abc import AsyncGenerator
 from datetime import timedelta
-from typing import TYPE_CHECKING, Optional, Union
+from typing import TYPE_CHECKING
 from unittest.mock import AsyncMock, Mock, patch
 
 import pytest
@@ -25,7 +25,7 @@ from strawberry.subscriptions.protocols.graphql_transport_ws.types import (
     SubscribeMessage,
 )
 from tests.http.clients.base import DebuggableGraphQLTransportWSHandler
-from tests.views.schema import MyExtension, Schema, Subscription
+from tests.views.schema import MyExtension, Schema, Subscription, schema
 
 if TYPE_CHECKING:
     from tests.http.clients.base import HttpClient, WebSocketClient
@@ -53,7 +53,7 @@ def assert_next(
     next_message: NextMessage,
     id: str,
     data: dict[str, object],
-    extensions: Optional[dict[str, object]] = None,
+    extensions: dict[str, object] | None = None,
 ):
     """
     Assert that the NextMessage payload contains the provided data.
@@ -154,7 +154,9 @@ async def test_ws_message_frame_types_cannot_be_mixed(ws_raw: WebSocketClient):
 
 
 async def test_connection_init_timeout(http_client_class: type[HttpClient]):
-    test_client = http_client_class(connection_init_wait_timeout=timedelta(seconds=0))
+    test_client = http_client_class(
+        schema, connection_init_wait_timeout=timedelta(seconds=0)
+    )
 
     async with test_client.ws_connect(
         "/graphql", protocols=[GRAPHQL_TRANSPORT_WS_PROTOCOL]
@@ -196,7 +198,7 @@ async def test_connection_init_timeout_cancellation(
 @pytest.mark.xfail(reason="This test is flaky")
 async def test_close_twice(mocker: MockerFixture, http_client_class: type[HttpClient]):
     test_client = http_client_class(
-        connection_init_wait_timeout=timedelta(seconds=0.25)
+        schema, connection_init_wait_timeout=timedelta(seconds=0.25)
     )
 
     async with test_client.ws_connect(
@@ -1074,9 +1076,9 @@ async def test_subsciption_cancel_finalization_delay(ws: WebSocketClient):
     )
 
     while True:
-        next_or_complete_message: Union[
-            NextMessage, CompleteMessage
-        ] = await ws.receive_json()
+        next_or_complete_message: (
+            NextMessage | CompleteMessage
+        ) = await ws.receive_json()
 
         assert next_or_complete_message["type"] in ("next", "complete")
 
